% Figs_PSD.m
% Plot fig for narrowband filter and PSD.
%
% Nick Kingsbury, Cambridge University, Oct 2002.


pos1 = [0.1 0.2 0.8 0.5];

fmin = -200;
fmax = 200;
f = [fmin:fmax]';
f0 = [90 100]';
f0a = [f0(1); f0; f0(2)];
h0a = [0; 1; 1; 0];
t1 = find((f >= -f0(2)) & (f <= -f0(1)));
t2 = find((f >= f0(1)) & (f <= f0(2)));


Sx = exp(-(f-80).^2/60^2) + exp(-(f+80).^2/60^2) + exp(-f.^2/20^2);

fontsz = 12;
setfig(1)
subplot('position',pos1);
% Plot axes
os = 2;
plot([fmin; fmax]*[1 1 0 0],[0 os 0 os; 0 os 1.5 os+1.5],'k','LineWidth',0.5);
%axis([-3.5 1.5 -1.5 3.5]);
axis off
set(gcf,'Color',[1 1 1]);
hold on
plot([-f0a f0a],[h0a h0a]+os,'r','LineWidth',2);
plot([-f0(1); f0(1)],[1;1]*(os+1),':k','LineWidth',0.5);
fill(f([t1(1); t1; t1(end)]),[0; Sx(t1); 0],[0.8 0.8 1]);
fill(f([t2(1); t2; t2(end)]),[0; Sx(t2); 0],[0.8 0.8 1]);
plot(f,Sx,'LineWidth',2)
hold off
text(0,-0.05,'0','horiz','cen','vert','top','FontSize',fontsz);
text(0,os-0.05,'0','horiz','cen','vert','top','FontSize',fontsz);
latext(f0(1),os-0.03,'\w_0','tr',fontsz);
latext(f0(2),os-0.03,'\w_0+\d\w','tl',fontsz);
latext(-f0(1),os-0.03,'-\w_0','tl',fontsz);
latext(-f0(2),os-0.03,'-\w_0-\d\w','tr',fontsz);
latext(f0(1),0.5,'\pP_o ','r',fontsz);
latext(-f0(1),0.5,' \pP_o','l',fontsz);
latext(0,os+1.02,'1 ','br',fontsz);
latext(0,os+1.3,'H(\w) ','br',fontsz);
latext(0,1.4,'S_x(\w) ','br',fontsz);
latext(0.9*fmax,-0.03,'\w ->','t',fontsz);
latext(0.9*fmax,os-0.03,'\w ->','t',fontsz);

return

print -depsc '\1ngk\TEX\Probability\Figures\phys_PSD'

