% Figs_det.m
% Illustrate detection of a binary signal in noise.
%
% Nick Kingsbury, Cambridge University, Oct 2002.

clear all

pos1 = [0.06 0.3 0.9 0.3]; % Use subplot so text is a reasonable size.

if ~exist('d'), rand('state',0); randn('state',0); end

nbits = 50;
ns = 20;
d = 2*round(rand(nbits+1,1)) - 1;  % random bits: +1 or -1.
x = kron(d,ones(ns,1));
N = ns * nbits;
t = [1:N]';

setfig(1)
subplot('position',pos1);
plot((t-0.5)/ns,x(t+ns/2),'LineWidth',2);
axis([0 nbits -2 2])
grid on
title('(a) Transmitted binary signal','FontSize',12);
xlabel('bits','FontSize',12);

h = sin([1:ns-1]'*pi/(ns));
h = h / sum(h);

noise = conv(2*randn(N+ns,1),h);

xf = conv(x,h);
setfig(2)
subplot('position',pos1);
plot((t-0.5)/ns,xf(t+ns-1),'LineWidth',2);
axis([0 nbits -2 2])
grid on
title('(b) Filtered signal','FontSize',12);
xlabel('bits','FontSize',12);

setfig(3)
subplot('position',pos1);
plot((t-0.5)/ns,noise(t+ns-1),'LineWidth',2);
axis([0 nbits -2 2])
grid on
title('(c) Filtered noise','FontSize',12);
xlabel('bits','FontSize',12);

yf = xf + noise;
setfig(4)
subplot('position',pos1);
plot((t-0.5)/ns,yf(t+ns-1),'LineWidth',2);
axis([0 nbits -2 2])
grid on
title('(d) Signal + noise at the detector','FontSize',12);
xlabel('bits','FontSize',12);


% pdf and cdf of Normal distr with mean 2 and variance 3.
sig = sqrt(0.4);
xmin = -3;
xmax = 3;
dx = 1/16;
x = [xmin:dx:xmax]';
y1 = exp(-(x-1).^2/(2*sig.^2)) / (sqrt(2*pi)*sig);
y2 = exp(-(x+1).^2/(2*sig.^2)) / (sqrt(2*pi)*sig);
setfig(5)
subplot('position',pos1);
plot(0,0)
axis([xmin xmax -0.2 0.8]);
hold on
i1=find(x <= 0);
fill([x(i1); 0],[y1(i1); 0],[0.8 0.8 1])
plot(x,[y1 y2],'LineWidth',2)
plot([0;0],[-1 2],'--r','LineWidth',2);
hold off
grid on
text(1,0.7,'data = +1','horiz','cen','FontSize',12);
text(-1,0.7,'data = -1','horiz','cen','FontSize',12);
text(-0.5,-0.1,'prob. of error','horiz','cen','FontSize',12);
title('pdfs of signal + noise at the detector','FontSize',12);
xlabel('R','FontSize',12);

return

figure(1)
print -depsc '\1ngk\TEX\Probability\Figures\txdata'
figure(2)
print -depsc '\1ngk\TEX\Probability\Figures\filtdata'
figure(3)
print -depsc '\1ngk\TEX\Probability\Figures\noise'
figure(4)
print -depsc '\1ngk\TEX\Probability\Figures\rxdata'
figure(5)
print -depsc '\1ngk\TEX\Probability\Figures\det_pdfs'


