% Figs_func.m
% Plot method of finding pdf of g(X).
%
% Nick Kingsbury, Cambridge University, Oct 2002.

% pdf of triangular distr with limits at -1 and +1..
xmin = -1;
xmax = 1;
dx = 1/16;
x = [xmin:dx:xmax]';
fx = max(1 - abs(x), 0);
fx = fx / (sum(fx)*dx);

K = [-0.4   1   0.4]';
y = [ones(size(x))  x  x.*x] * K;
grad = [ones(size(x))  2*x] * K([2;3]);

fy = fx ./ max(grad,1e-10); 

os = 2;
ix = round([0.2 0.25 0.75 0.8]*(xmax-xmin)/dx);
setfig(1)
% subplot('position',pos1);
% Plot axes
plot([-5 5;0 0]',[0 0;-5 5]','k','LineWidth',0.5);
axis([-3.5 1.5 -1.5 3.5]);
axis square
hold on
t = [1 2 2 1];
fill(x(ix(t)),fx(ix(t)).*[1;1;0;0]+os,[0.8 0.8 1])
fill(-fy(ix(t)).*[1;1;0;0]-os,y(ix(t)),[0.8 0.8 1])
t = t + 2;
fill(x(ix(t)),fx(ix(t)).*[1;1;0;0]+os,[1 0.8 0.8])
fill(-fy(ix(t)).*[1;1;0;0]-os,y(ix(t)),[1 0.8 0.8])
plot([-1.5 5;-os -os]',[os os;-5 1.5]','k','LineWidth',0.5);
plot(x,fx+os,'LineWidth',2)
plot(x,y,'LineWidth',2)
plot(-fy-os,y,'LineWidth',2)
plot([1;1]*x(ix)',[fx(ix)+os  y(ix)]','--g','LineWidth',2)
plot([-fy(ix)-os  x(ix)]',[1;1]*y(ix)','--g','LineWidth',2)
hold off
title('Calculating the pdf of Y = g(X)','FontSize',12);
text(1.2,-0.05,'X','horiz','cen','vert','top','FontSize',12);
text(1.2,os-0.05,'X','horiz','cen','vert','top','FontSize',12);
text(-0.05,os+1.1,'fx','horiz','right','vert','mid','FontSize',12);
text(-0.05,1.2,'Y','horiz','right','vert','mid','FontSize',12);
text(-os-0.05,1.2,'Y','horiz','right','vert','mid','FontSize',12);
text(-os-1.1,-0.05,'fy','horiz','cen','vert','top','FontSize',12);

text(x(ix(2)),os+0.25,' A','horiz','left','vert','mid','FontSize',12);
text(x(ix(3)),os+0.25,'C ','horiz','right','vert','mid','FontSize',12);
text(-os-0.4,y(ix(2))+0.02,'B','horiz','cen','vert','bot','FontSize',12);
text(-os-0.1,y(ix(4))+0.02,'D','horiz','cen','vert','bot','FontSize',12);

text(-os-0.5,os+0.9,'area B = area A','horiz','cen','vert','mid','FontSize',12)
text(-os-0.5,os+0.6,'area D = area C','horiz','cen','vert','mid','FontSize',12)
text(0.15,-0.3,'Y = g(X)','horiz','left','vert','top','FontSize',12)

return

print -depsc '\1ngk\TEX\Probability\Figures\func_pdf'

