% Figs_func2.m
% Plot method of finding pdf of g(X) for Uniform-to-Gaussian case.
% Because there is no explicit solution, we need to start with y
% and work back to x.
%
% Nick Kingsbury, Cambridge University, Oct 2002.

% pdf of uniform distr with limits at 0 and +1..
ymin = -3;
ymax = 3;
dy = 1/128;
sigma = 1;

y = [ymin:dy:ymax]';
fy = exp(-y.*y/2) / sqrt(2*pi);
x = cumsum(fy) * dy;
fx = ones(size(y));

osx = 1;
osy = 4;
ix = round([0.38 0.43 0.69 0.8]*length(x));
setfig(2)
% subplot('position',pos1);
% Plot axes
plot([-5 5;0 0]',[0 0;-5 7]','k','LineWidth',0.5);
axis([-2.5 1.5 -3 5.5]);
axis square
hold on
t = [1 2 2 1];
fill(x(ix(t)),fx(ix(t)).*[1;1;0;0]+osy,[0.8 0.8 1])
fill(-fy(ix(t)).*[1;1;0;0]-osx,y(ix(t)),[0.8 0.8 1])
t = t + 2;
fill(x(ix(t)),fx(ix(t)).*[1;1;0;0]+osy,[1 0.8 0.8])
fill(-fy(ix(t)).*[1;1;0;0]-osx,y(ix(t)),[1 0.8 0.8])
plot([-0.8*osx 5;-osx -osx]',[osy osy;-5 0.9*osy]','k','LineWidth',0.5);
plot([0;x;1],[0;fx;0]+osy,'LineWidth',2)
plot(x,y,'LineWidth',2)
plot(-fy-osx,y,'LineWidth',2)
plot([1;1]*x(ix)',[fx(ix)+osy  y(ix)]','--g','LineWidth',2)
plot([-fy(ix)-osx  x(ix)]',[1;1]*y(ix)','--g','LineWidth',2)
hold off
title('(a) Converting a uniform pdf, fx, to a Gaussian pdf, fy','FontSize',12);
text(1.2,-0.05,'X','horiz','cen','vert','top','FontSize',12);
text(1.2,osy-0.05,'X','horiz','cen','vert','top','FontSize',12);
text(-0.05,osy+1.1,'fx','horiz','right','vert','mid','FontSize',12);
text(-0.05,3,'Y','horiz','right','vert','mid','FontSize',12);
text(-osx+0.05,3,'Y','horiz','left','vert','mid','FontSize',12);
text(-osx-0.5,-0.05,'fy','horiz','cen','vert','top','FontSize',12);

text(x(ix(2)),osy+0.5,' A','horiz','left','vert','mid','FontSize',12);
text(x(ix(3)),osy+0.5,'C ','horiz','right','vert','mid','FontSize',12);
text(-osx-0.15,y(ix(2))+0.02,'B','horiz','cen','vert','bot','FontSize',12);
text(-osx-0.1,y(ix(3))-0.02,'D','horiz','cen','vert','top','FontSize',12);

text(-osx-0.5,osy+0.9,'area B = area A','horiz','cen','vert','mid','FontSize',12)
text(-osx-0.5,osy+0.6,'area D = area C','horiz','cen','vert','mid','FontSize',12)
text(0.25,-0.8,'Y = g(X)','horiz','left','vert','top','FontSize',12)

return

print -depsc '\1ngk\TEX\Probability\Figures\func2_pdf'

