% Figs_func3.m
% Plot method of finding pdf of g(X) for Uniform-to-Rayleigh case.
%
% Nick Kingsbury, Cambridge University, Oct 2002.

% pdf of uniform distr with limits at 0 and +1..
xmin = 0;
xmax = 0.998;
dx = 1/256;
sigma = 1;

x = [xmin:dx:xmax]';
fx = ones(size(x));
fx = fx / (sum(fx)*dx);

y = sigma * sqrt(-2*log(max(1-x,1e-9)));
inv_grad = y .* (1-x) / sigma^2;

fy = fx .* inv_grad; 

osx = 1;
osy = 4;
ix = round([0.3 0.4 0.85 0.95]*(xmax-xmin)/dx);
setfig(3)
% subplot('position',pos1);
% Plot axes
plot([-5 5;0 0]',[0 0;-5 7]','k','LineWidth',0.5);
axis([-2.5 1.5 -0.5 5.5]);
axis square
hold on
t = [1 2 2 1];
fill(x(ix(t)),fx(ix(t)).*[1;1;0;0]+osy,[0.8 0.8 1])
fill(-fy(ix(t)).*[1;1;0;0]-osx,y(ix(t)),[0.8 0.8 1])
t = t + 2;
fill(x(ix(t)),fx(ix(t)).*[1;1;0;0]+osy,[1 0.8 0.8])
fill(-fy(ix(t)).*[1;1;0;0]-osx,y(ix(t)),[1 0.8 0.8])
plot([-0.8*osx 5;-osx -osx]',[osy osy;-5 0.9*osy]','k','LineWidth',0.5);
plot([xmin;x;xmax],[0;fx;0]+osy,'LineWidth',2)
plot(x,y,'LineWidth',2)
plot(-fy-osx,y,'LineWidth',2)
plot([1;1]*x(ix)',[fx(ix)+osy  y(ix)]','--g','LineWidth',2)
plot([-fy(ix)-osx  x(ix)]',[1;1]*y(ix)','--g','LineWidth',2)
hold off
title('(b) Converting a uniform pdf, fx, to a Rayleigh pdf, fy','FontSize',12);
text(1.2,-0.05,'X','horiz','cen','vert','top','FontSize',12);
text(1.2,osy-0.05,'X','horiz','cen','vert','top','FontSize',12);
text(-0.05,osy+1.1,'fx','horiz','right','vert','mid','FontSize',12);
text(-0.05,3,'Y','horiz','right','vert','mid','FontSize',12);
text(-osx+0.05,3,'Y','horiz','left','vert','mid','FontSize',12);
text(-osx-0.5,-0.05,'fy','horiz','cen','vert','top','FontSize',12);

text(x(ix(2)),osy+0.5,' A','horiz','left','vert','mid','FontSize',12);
text(x(ix(3)),osy+0.5,'C ','horiz','right','vert','mid','FontSize',12);
text(-osx-0.3,y(ix(2))+0.02,'B','horiz','cen','vert','bot','FontSize',12);
text(-osx-0.15,y(ix(3))-0.02,'D','horiz','cen','vert','top','FontSize',12);

text(-osx-0.5,osy+0.9,'area B = area A','horiz','cen','vert','mid','FontSize',12)
text(-osx-0.5,osy+0.6,'area D = area C','horiz','cen','vert','mid','FontSize',12)
text(0.6,1.2,'Y = g(X)','horiz','left','vert','top','FontSize',12)

return

print -depsc '\1ngk\TEX\Probability\Figures\func3_pdf'

